<?php
/**
 * This file generates a Makefile to process the static resources in /rsrc.
 * The process consists in:
 *
 *   - Minifying CSS and JS files using the Google closure tools.
 *   - Copying the new files to the /res directory with the names specified
 *     in the resource map.
 *
 * @author Albert Almeida (caviola@gmail.com)
 */

if (empty($argv[1])) {
	die("Usage: php build-resource-makefile.php <path to resource map file>\n");
}

$filepath = $argv[1];
if (!file_exists($filepath)) {
	die("ERROR: The file {$filepath} doesn't exists.\n");
}

include $filepath;
if (!isset($__resource_map)) {
	die("ERROR: \$__resource_map is not defined inside {$filepath}.\n");
}

echo <<<MSG
WEBROOT = ../webroot
COMPILE_CSS = java -jar closure-stylesheets.jar
COMPILE_JS = java -jar closure-compiler.jar
EXPAND = php -d auto_prepend_file=$(WEBROOT)/__init.inc

MSG;

$all = array();
foreach($__resource_map as $target) {
	$all[] = '$(WEBROOT)/res/' . $target;
}
echo 'all: ' . implode(' ', $all);
echo "\n";

foreach($__resource_map as $source => $target) {
	echo '$(WEBROOT)/res/' . $target . ': ' . '$(WEBROOT)/rsrc/' . $source . '; ';

	// Generate the command to expand and compile .css and .js files.
	// For .min.css, .min.js files and all other resources, we generate a simple
	// copy operation.
	if (ends_with($source, '.css') && !ends_with($source, '.min.css')) {
		echo "$(EXPAND) -f $< | $(COMPILE_CSS) /dev/stdin > $@\n";
	} elseif (ends_with($source, '.js') && !ends_with($source, '.min.js')) {
		echo "$(EXPAND) -f $< | $(COMPILE_JS) > $@\n";
	} else {
		echo "cp $< $@\n";
	}
	$m[] = '';
}


function ends_with($str, $suffix) {
	return substr($str, -strlen($suffix)) == $suffix;
}
