#!/bin/bash

#
# @author Albert Almeida (caviola@gmail.com)
#

if ! which ack-grep > /dev/null; then
	echo "'ack-grep' not found. Install it with: apt-get install ack-grep"
	exit 1
fi

trap "exit" INT

UTILS=$PWD
WEBROOT=$PWD/../webroot
RESOURCE_MAP=$UTILS/__resource_map.csv
EXPAND="php -d auto_prepend_file=$WEBROOT/__init.inc -f"

echo "Building resources"
cp /dev/null $RESOURCE_MAP

cd $WEBROOT/rsrc
for original in `ack-grep -fa`; do
	echo "Hashing $original"

	ext=${original##*.}

	case $original in
		*.min.js|*.min.css)
			hash=`md5sum $original | cut -c1-8`
			;;

		*.js|*.css)
			hash=`$EXPAND $original | md5sum | cut -c1-8`
			;;

		*)
			hash=`md5sum $original | cut -c1-8`
			;;
	esac

	echo "$hash.$ext:$original" >> $RESOURCE_MAP
done

cd $UTILS
php build-resource-map.php > $WEBROOT/__resource_map.inc

cd $WEBROOT/rsrc
for line in `cat $UTILS/__resource_map.csv`; do
	compiled=`echo $line | cut -d: -f1`
	original=`echo $line | cut -d: -f2`

	case $original in
		*.min.js|*.min.css)
			echo "Copying $original to res/$compiled"
			cp $original "$WEBROOT/res/$compiled"
			;;

		*.js)
			echo "Optimizing $original to res/$compiled"
			$EXPAND $original | java -jar $UTILS/closure-compiler.jar > "$WEBROOT/res/$compiled"
			;;

		*.css)
			echo "Optimizing $original to res/$compiled"
			$EXPAND $original | java -jar $UTILS/closure-stylesheets.jar /dev/stdin > "$WEBROOT/res/$compiled"
			;;

		*)
			echo "Copying $original to res/$compiled"
			cp $original "$WEBROOT/res/$compiled"
			;;
	esac
done
